from numpy import * 
from matplotlib.pyplot import *
from ainsliemccolm     import *
from francoisgarrison  import *
from rhodes            import *
from thorp             import *

print("Comparing absorption coefficients...")

nfreqs = 101
fmin =     1
fmax =  1000
n = linspace(0,3,101)
freqs = 10**n

S  = 35.0
T  =  5.0
pH =  8.0
Z  =  0.0
c  = 1450.0
e  =  2.5 

a_a = ainsliemccolm(   freqs, S, T, pH, Z)
a_f = francoisgarrison(freqs, S, T, pH, Z)
a_r = rhodes(          freqs, S, T, pH, Z, c, e)

alpha = thorp(freqs*1000)

adB_m = alpha*20.0/log(10.0)
a_t = 1000*adB_m

fig = figure(1)
ax = fig.add_subplot(1,1,1)
ax.plot(freqs,a_a,'y',linewidth=3,label='Ainslie and McColm')
ax.plot(freqs,a_f,'b',linewidth=3,label='Francois and Garrison')
ax.plot(freqs,a_r,'r',linewidth=3,label='Rhodes')
ax.plot(freqs,a_t,'k',linewidth=3,label='Thorp')
ax.set_xscale('log')
ax.set_yscale('log')
xlabel('Frequency (kHz)',fontsize=18)
ylabel(r'$\alpha$ (dB/km)',fontsize=18)
xlim(1,1000)
ylim(0.1,1000)
legend(loc=2)
grid(True)

show()

print("done.")
